%global debug_package %{nil}

# rpmbuild < 4.6 support
%if ! 0%{?__isa_bits}
%ifarch x86_64 ia64 ppc64 sparc64 s390x alpha ppc64le aarch64
%global __isa_bits 64
%else
%global __isa_bits 32
%endif
%endif

Name:          leveldbjni
Version:       1.8
Release:       15.7%{?dist}
Summary:       A Java Native Interface to LevelDB
License:       BSD
URL:           https://github.com/fusesource/leveldbjni/
Source0:       https://github.com/fusesource/leveldbjni/archive/%{name}-%{version}.tar.gz

Patch0001:     0001-leveldb-api.patch
Patch0002:     0002-javadoc.patch

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires: mvn(org.apache.maven.plugin-tools:maven-plugin-tools-javadoc)
BuildRequires: mvn(org.fusesource:fusesource-pom:pom:)
BuildRequires: mvn(org.fusesource.hawtjni:hawtjni-runtime)
BuildRequires: mvn(org.fusesource.hawtjni:maven-hawtjni-plugin)
# see https://bugzilla.redhat.com/show_bug.cgi?id=881608
BuildRequires: pkgconfig(leveldb) >= 1.7.0-4
BuildRequires: snappy-devel
BuildRequires: xmvn

Requires:      leveldb
Requires:      snappy
Requires:      %{name}-all%{?_isa} = %{version}-%{release}

%description
LevelDB JNI gives you a Java interface to the
LevelDB C++ library which is a fast key-value
storage library written at Google that provides
an ordered mapping from string keys to string
values.

%package all
Summary:       %{name} with bundled dependencies
Requires:      leveldb
Requires:      snappy

%description all
This package contains %{name} along with all its dependencies in a single JAR.

%package javadoc
Summary:       Javadoc for %{name}
BuildArch:     noarch

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
%autopatch -p1

%pom_remove_plugin :jxr-maven-plugin
%pom_remove_plugin :surefire-report-maven-plugin
# disable non linux module
%pom_remove_dep org.fusesource.%{name}:%{name}-osx %{name}-all
%pom_remove_dep org.fusesource.leveldbjni:leveldbjni-win32 %{name}-all
%pom_remove_dep org.fusesource.leveldbjni:leveldbjni-win64 %{name}-all

# Use local copy of leveldb-api
%pom_remove_dep org.iq80.leveldb:leveldb-api %{name}

%pom_xpath_remove "pom:Private-Package" %{name}-all
%pom_xpath_remove "pom:Export-Package" %{name}-all
%pom_xpath_remove "pom:Import-Package" %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Export-Package>
 org.fusesource.leveldbjni;uses:="org.iq80.leveldb";version=${project.version},
 org.iq80.leveldb;version="${leveldb-api-version}"
</Export-Package>' %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Private-Package>
 org.fusesource.hawtjni*,
 org.fusesource.leveldbjni.internal*,
 org.iq80.leveldb*
</Private-Package>' %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Import-Package>
 !org.iq80.leveldb
</Import-Package>' %{name}-all

%pom_xpath_remove "pom:Bundle-NativeCode"  %{name}-all

%if %{__isa_bits} == 64

%pom_remove_dep org.fusesource.%{name}:%{name}-linux32 %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" "
<Bundle-NativeCode>
  META-INF/native/linux64/libleveldbjni.so;osname=Linux;processor=%{_arch}
</Bundle-NativeCode>" %{name}-all

%else

%pom_remove_dep org.fusesource.%{name}:%{name}-linux64 %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" "
<Bundle-NativeCode>
  META-INF/native/linux32/libleveldbjni.so;osname=Linux;processor=%{_arch}
</Bundle-NativeCode>" %{name}-all

%endif

rm -r %{name}/src/test/java/org/fusesource/%{name}/test/DBTest.java
cp -f /usr/lib/rpm/config.{sub,guess} /usr/share/automake-*/compile leveldbjni/src/main/native-package/autotools/

%pom_remove_plugin :maven-jar-plugin %{name}
%pom_add_plugin org.apache.maven.plugins:maven-jar-plugin:3.0.2 %{name} '
<configuration>
  <archive>  
    <manifestFile>${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>
  </archive> 
</configuration>'

%mvn_package :leveldbjni-all all

%build

%ifarch ppc64
export MAVEN_OPTS='-Xms1024m -Xmx2048m -XX:MaxPermSize=384m'
%endif
%mvn_file :%{name}-all %{name}-all
%mvn_file :%{name}-linux%{__isa_bits} %{name}-linux
export JAVA_HOME=%{_jvmdir}/java LEVELDB_HOME=%{_prefix} SNAPPY_HOME=%{_prefix}
%mvn_build -- -Plinux%{__isa_bits},all -Dleveldb=%{_prefix} -Dsnappy=%{_prefix}

%install
%mvn_install

%files  -f .mfiles
%doc changelog.md readme.md releasing.md
%license license.txt

%files all -f .mfiles-all
%doc changelog.md readme.md releasing.md
%license license.txt

%files javadoc -f .mfiles-javadoc
%license license.txt

%changelog
* Wed Jan 24 2018 Stephen Kitt <skitt@redhat.com> - 1.18-15.7
- Explicitly prevent importing the leveldb package (#1532251)

* Wed Jan 24 2018 Stephen Kitt <skitt@redhat.com> - 1.8-15.6
- No-change rebuild to address #1532251

* Fri Jul 28 2017 Stephen Kitt <steve@sk2.org> - 1.8-15.5
- Fix leveldbjni's dependency on leveldbjni-all

* Thu Jul 27 2017 Stephen Kitt <steve@sk2.org> - 1.8-15.4
- Split out the über-JAR into a -all package (thanks to Yaakov Selkowitz for the
  initial patch)

* Wed Jul 26 2017 Mike Burns <mburns@redhat.com> - 1.8-15.3
- rebuild for ppc64le

* Thu Jul 13 2017 Stephen Kitt <skitt@redhat.com> - 1.8-15.2
- Add explicit dependencies on leveldb and
  snappy (the embedded .so requires them)

* Wed Jul 12 2017 Stephen Kitt <skitt@redhat.com> - 1.8-15.1
- Temporarily bundle leveldb-api
- Fix Javadoc errors
- Adjust the -all bundle to match the upstream bundle

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Aug 09 2016 gil cattaneo <puntogil@libero.it> 1.8-14
- add missing build requires: xmvn
- prevent duplicate pom BR entries

* Tue Jun 21 2016 gil cattaneo <puntogil@libero.it> 1.8-13
- add missing build requires: maven-bundle-plugin

* Thu May 05 2016 daviddavid <daviddavid> 1.8-12
- explicitly call "compile" file from automake to make it build

* Tue Apr 12 2016 gil cattaneo <puntogil@libero.it> 1.8-11
- fix Missing class in leveldbjni-all.jar (rhbz#1326445)

* Tue Feb 09 2016 gil cattaneo <puntogil@libero.it> 1.8-10
- fix BR list (use mvn,pkgconfig()-like)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Feb 10 2015 gil cattaneo <puntogil@libero.it> 1.8-7
- introduce license macro

* Fri Sep 19 2014 Karsten Hopp <karsten@redhat.com> 1.8-6
- update config.sub to support ppc64le
- set MAVEN_OPTS on ppc64 to work around java.lang.StackOverflowError

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 28 2014 Peter Robinson <pbrobinson@fedoraproject.org> 1.8-4
- Add a better 32/64 architecture detection

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 08 2014 gil cattaneo <puntogil@libero.it> 1.8-2
- fix leveldbjni-all.jar

* Tue Apr 22 2014 gil cattaneo <puntogil@libero.it> 1.8-1
- update to 1.8

* Sun Aug 18 2013 gil cattaneo <puntogil@libero.it> 1.7-1
- update to 1.7

* Fri Sep 07 2012 gil cattaneo <puntogil@libero.it> 1.2-1
- initial rpm
